# Jupyter ProtoPype: jppype
[![NPM Version](https://img.shields.io/npm/v/async-assets-loader.svg?style=flat-square)](https://www.npmjs.com/package/async-assets-loader)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg?style=flat-square)](LICENSE)
[![NPM Downloads](https://img.shields.io/npm/dt/async-assets-loader.svg?style=flat-square)](https://www.npmjs.com/package/async-assets-loader)

Custom Jupyter Widgets for ProtoPype.

Package Install
---------------

**Prerequisites**
- [node](http://nodejs.org/)

```bash
npm install --save jppype
```


Build
-----

```bash
jlpm build
```